==> mcu_plus_sdk_am64x_08_00_00_21_docs_only.tar.xz: mcu_plus_sdk_am64x_08_00_00_21_docs_only/docs/industrial_protocol_docs/am64x/ethercat_slave/group___e_c___a_p_i___s_l_v___o_b_d.js <==
var group___e_c___a_p_i___s_l_v___o_b_d =
[
    [ "EC_API_SLV_CoE_getObject", "group___e_c___a_p_i___s_l_v___o_b_d_gad932355ebef489a7ac86f3da447ff85c.html#gad932355ebef489a7ac86f3da447ff85c", null ],
    [ "EC_API_SLV_CoE_getObjectData", "group___e_c___a_p_i___s_l_v___o_b_d_gaac0a281e5c01746c049e4819ee13880e.html#gaac0a281e5c01746c049e4819ee13880e", null ],
    [ "EC_API_SLV_CoE_setObjectData", "group___e_c___a_p_i___s_l_v___o_b_d_gab613fe9b79b0fb2d12fb7b743e873aa9.html#gab613fe9b79b0fb2d12fb7b743e873aa9", null ],
    [ "EC_API_SLV_CoE_getObjectEntryCount", "group___e_c___a_p_i___s_l_v___o_b_d_ga5901d47118ca774133077f692d25736c.html#ga5901d47118ca774133077f692d25736c", null ],
    [ "EC_API_SLV_CoE_getObjectType", "group___e_c___a_p_i___s_l_v___o_b_d_gaf2b0980f1128220c451b8887612de7b6.html#gaf2b0980f1128220c451b8887612de7b6", null ],
    [ "EC_API_SLV_CoE_getObjectEntry", "group___e_c___a_p_i___s_l_v___o_b_d_gafd4adb4cea1753761933fa44dab069e9.html#gafd4adb4cea1753761933fa44dab069e9", null ],
    [ "EC_API_SLV_CoE_getObjectEntryData", "group___e_c___a_p_i___s_l_v___o_b_d_gacd07cb8a584e8b3fe26003540a7b791d.html#gacd07cb8a584e8b3fe26003540a7b791d", null ],
    [ "EC_API_SLV_CoE_setObjectEntryData", "group___e_c___a_p_i___s_l_v___o_b_d_gafb85ca8d8e15690d4461f7ac6cbb273f.html#gafb85ca8d8e15690d4461f7ac6cbb273f", null ],
    [ "EC_API_SLV_CoE_generateObjectDict", "group___e_c___a_p_i___s_l_v___o_b_d_gaf4865921bcb4d7e89897af0cbc6a0c67.html#gaf4865921bcb4d7e89897af0cbc6a0c67", null ],
    [ "EC_API_SLV_CoE_odAddVariable", "group___e_c___a_p_i___s_l_v___o_b_d_ga893f2eb85de6dcdea45a03fef3b40ae5.html#ga893f2eb85de6dcdea45a03fef3b40ae5", null ],
    [ "EC_API_SLV_CoE_odAddArray", "group___e_c___a_p_i___s_l_v___o_b_d_ga4e2ad8d61fa107759c4991e3b282e653.html#ga4e2ad8d61fa107759c4991e3b282e653", null ],
    [ "EC_API_SLV_CoE_odAddRecord", "group___e_c___a_p_i___s_l_v___o_b_d_gaf7ec3f42b2830dd02f5863b60abbb9a3.html#gaf7ec3f42b2830dd02f5863b60abbb9a3", null ],
    [ "EC_API_SLV_CoE_configRecordSubIndex", "group___e_c___a_p_i___s_l_v___o_b_d_ga57b67e9013576a9952e8bc17c71997bc.html#ga57b67e9013576a9952e8bc17c71997bc", null ],
    [ "EC_API_SLV_CoE_subIdx0WrFlag", "group___e_c___a_p_i___s_l_v___o_b_d_ga16a0f3cc997cdbbb2dbecbf135d91323.html#ga16a0f3cc997cdbbb2dbecbf135d91323", null ]
];

==> mcu_plus_sdk_am64x_08_01_00_36_docs_only.tar.xz: mcu_plus_sdk_am64x_08_01_00_36_docs_only/docs/industrial_protocol_docs/am64x/ethercat_slave/group___e_c___a_p_i___s_l_v___o_b_d.js <==
var group___e_c___a_p_i___s_l_v___o_b_d =
[
    [ "EC_API_SLV_CoE_getObject", "group___e_c___a_p_i___s_l_v___o_b_d_gad932355ebef489a7ac86f3da447ff85c.html#gad932355ebef489a7ac86f3da447ff85c", null ],
    [ "EC_API_SLV_CoE_getObjectData", "group___e_c___a_p_i___s_l_v___o_b_d_gaac0a281e5c01746c049e4819ee13880e.html#gaac0a281e5c01746c049e4819ee13880e", null ],
    [ "EC_API_SLV_CoE_setObjectData", "group___e_c___a_p_i___s_l_v___o_b_d_gab613fe9b79b0fb2d12fb7b743e873aa9.html#gab613fe9b79b0fb2d12fb7b743e873aa9", null ],
    [ "EC_API_SLV_CoE_getObjectEntryCount", "group___e_c___a_p_i___s_l_v___o_b_d_ga5901d47118ca774133077f692d25736c.html#ga5901d47118ca774133077f692d25736c", null ],
    [ "EC_API_SLV_CoE_getObjectType", "group___e_c___a_p_i___s_l_v___o_b_d_gaf2b0980f1128220c451b8887612de7b6.html#gaf2b0980f1128220c451b8887612de7b6", null ],
    [ "EC_API_SLV_CoE_getObjectEntry", "group___e_c___a_p_i___s_l_v___o_b_d_ga83115662dd3aa0c37fdf6d5ffa9b0273.html#ga83115662dd3aa0c37fdf6d5ffa9b0273", null ],
    [ "EC_API_SLV_CoE_getObjectEntryByObject", "group___e_c___a_p_i___s_l_v___o_b_d_gaf4aee38e9d8ddf1e5fe0ada3efb05cdd.html#gaf4aee38e9d8ddf1e5fe0ada3efb05cdd", null ],
    [ "EC_API_SLV_CoE_getObjectEntryData", "group___e_c___a_p_i___s_l_v___o_b_d_gacd07cb8a584e8b3fe26003540a7b791d.html#gacd07cb8a584e8b3fe26003540a7b791d", null ],
    [ "EC_API_SLV_CoE_getObjectEntryDataByObject", "group___e_c___a_p_i___s_l_v___o_b_d_ga2a5f6989c9816b1e5734986364437166.html#ga2a5f6989c9816b1e5734986364437166", null ],
    [ "EC_API_SLV_CoE_setObjectEntryData", "group___e_c___a_p_i___s_l_v___o_b_d_gafb85ca8d8e15690d4461f7ac6cbb273f.html#gafb85ca8d8e15690d4461f7ac6cbb273f", null ],
    [ "EC_API_SLV_CoE_generateObjectDict", "group___e_c___a_p_i___s_l_v___o_b_d_gaf4865921bcb4d7e89897af0cbc6a0c67.html#gaf4865921bcb4d7e89897af0cbc6a0c67", null ],
    [ "EC_API_SLV_CoE_odAddVariable", "group___e_c___a_p_i___s_l_v___o_b_d_ga893f2eb85de6dcdea45a03fef3b40ae5.html#ga893f2eb85de6dcdea45a03fef3b40ae5", null ],
    [ "EC_API_SLV_CoE_odAddArray", "group___e_c___a_p_i___s_l_v___o_b_d_ga4e2ad8d61fa107759c4991e3b282e653.html#ga4e2ad8d61fa107759c4991e3b282e653", null ],
    [ "EC_API_SLV_CoE_odAddRecord", "group___e_c___a_p_i___s_l_v___o_b_d_gaf7ec3f42b2830dd02f5863b60abbb9a3.html#gaf7ec3f42b2830dd02f5863b60abbb9a3", null ],
    [ "EC_API_SLV_CoE_configRecordSubIndex", "group___e_c___a_p_i___s_l_v___o_b_d_ga57b67e9013576a9952e8bc17c71997bc.html#ga57b67e9013576a9952e8bc17c71997bc", null ],
    [ "EC_API_SLV_CoE_subIdx0WrFlag", "group___e_c___a_p_i___s_l_v___o_b_d_ga16a0f3cc997cdbbb2dbecbf135d91323.html#ga16a0f3cc997cdbbb2dbecbf135d91323", null ]
];
